@@ -36,6 +36,11 @@
 # define MBEDTLS_IS_BIG_ENDIAN 0
 #endif
 
+#define SB_SHA256_SIZE 32
+#define SB_SHA256_BLK 64
+#define SB_SIPH_SIZE 8
+#define SB_SKEY_SIZE 16
+
 typedef enum {
   MBEDTLS_SHA3_SHAKE256 = 0,
   MBEDTLS_SHA3_224,
@@ -72,16 +77,35 @@ typedef struct secretbase_sha3_context {
   mbedtls_sha3_context *ctx;
 } secretbase_sha3_context;
 
+typedef struct CSipHash {
+  uint64_t v0;
+  uint64_t v1;
+  uint64_t v2;
+  uint64_t v3;
+  uint64_t padding;
+  size_t n_bytes;
+} CSipHash;
+
 typedef struct secretbase_sha256_context {
   int skip;
   mbedtls_sha256_context *ctx;
 } secretbase_sha256_context;
 
+typedef struct secretbase_siphash_context {
+  int skip;
+  CSipHash *ctx;
+} secretbase_siphash_context;
+
+void clear_buffer(void *, size_t);
 SEXP hash_to_sexp(unsigned char *, size_t, int);
 
 SEXP secretbase_sha3(SEXP, SEXP, SEXP);
 SEXP secretbase_sha3_file(SEXP, SEXP, SEXP);
-SEXP secretbase_sha256(SEXP, SEXP);
-SEXP secretbase_sha256_file(SEXP, SEXP);
+SEXP secretbase_sha256(SEXP, SEXP, SEXP);
+SEXP secretbase_sha256_file(SEXP, SEXP, SEXP);
+SEXP secretbase_siphash13(SEXP, SEXP, SEXP);
+SEXP secretbase_siphash13_file(SEXP, SEXP, SEXP);
+SEXP secretbase_siphash24(SEXP, SEXP, SEXP);
+SEXP secretbase_siphash24_file(SEXP, SEXP, SEXP);
 
 #endif
